@@ -2,6 +2,6 @@ package local
 
 import "os/exec"
 
-func buildCmd(*exec.Cmd, bool) error {
+func buildCmd(*exec.Cmd) error {
 	return nil
 }
